@@ -81,7 +81,7 @@ struct _GeditAppPrivate
 	GtkPageSetup      *page_setup;
 	GtkPrintSettings  *print_settings;
 	
-	GSettings         *settings;
+	GObject           *settings;
 	GSettings         *window_settings;
 
 	PeasExtensionSet  *extensions;
@@ -123,10 +123,8 @@ gedit_app_dispose (GObject *object)
 
 	if (app->priv->extensions != NULL)
 	{
-		peas_extension_set_call (app->priv->extensions,
-					 "deactivate",
-					 app);
-
+		/* Note that unreffing the extensions will automatically remove
+		   all extensions which in turn will deactivate the extension */
 		g_object_unref (app->priv->extensions);
 		app->priv->extensions = NULL;
 	}
@@ -1124,7 +1122,7 @@ _gedit_app_set_default_print_settings (GeditApp         *app,
 	app->priv->print_settings = g_object_ref (settings);
 }
 
-GSettings *
+GObject *
 _gedit_app_get_settings (GeditApp *app)
 {
 	g_return_val_if_fail (GEDIT_IS_APP (app), NULL);
@@ -1132,4 +1130,4 @@ _gedit_app_get_settings (GeditApp *app)
 	return app->priv->settings;
 }
 
-/* ex:ts=8:noet: */
+/* ex:set ts=8 noet: */
